@@ -2,4 +2,4 @@
   "ghc"
   2.0.0
   "Sub mode for Haskell mode"
-  nil)
+  '((haskell-mode "13.0")))
